joblib: Lightweight pipelining with Python functions
====================================================

Description
-----------

Lightweight pipelining with Python functions

License
-------

Upstream Contact
----------------

https://pypi.org/project/joblib/

